#!/bin/bash
#
# packager         : Fred. Galusik <fredg> (fredgk~AT~gmail.com)
#
# source location  : http://developers.videolan.org/libdvdcss/
#
# last revised     : 08/10/2006
#
# additional files :
#

#
# what package is going to be built
#
# packageversion='1Z28' means:
# 1  -> build 1,
# Z  -> ZenWalk
# 30 -> ZenWalk version 3.0
#
softname='libdvdcss'
softversion='1.2.9'
packageversion='1z32'

#
# ZenWalk standard: CPU type and architecture
#
# arch='i486' -> the compiler uses only 80486 instructions
# cpu='i686'  -> the optimising is done for a PII and above CPU
#
arch='i486'
cpu='i686'

#
# the package 'destination'
#
prefix=/usr

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "heavy" computer: 6 build-jobs at once
#
# numjobs='-j6'
#
# "light" computer: 2 build-jobs at once
#
numjobs='-j2'

#
# parameters needed for the build process
#
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

#
# prepare the build result directory
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix
mkdir -p $dest/usr/src/$softname-$softversion

#
# put slack-desc in place. Either a supplied one, or some default
# text.
#
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: $softname
$softname:
$softname: libdvdcss is a simple library designed for accessing DVDs  
$softname: like a block device without having to bother about the decryption.
$softname:
$softname:
$softname:
$softname:
$softname: Built for ZenWalk
$softname:
$softname: by fred Galusik
EOF

#
# extract the source code
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar zxvf $srcpkg
cd $src

#
# configure package for compilation
#

    export CFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --sysconfdir=/etc \
      --localstatedir=/var/lib \
      --program-prefix="" \
      --program-suffix="" \

#
# make package
#
    make $numjobs DESTDIR=$dest

#
# install package to the target directory
#
    make install DESTDIR=$dest

#
# add 'default' files
#
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      ABOUT-NLS AUTHORS COPYING INSTALL NEWS README TODO \
      $dest/usr/doc/$softname-$softversion

#
# Strip Executables
# (Comment out these lines if debugging info is needed)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Compress Man Pages
#
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

#
# put the ZenWalk build in the right directory
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# set target permissions
#
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;
#
# real packaging work:
#
cd $dest
makepkg -l y -c n $dest.tgz
#
# computes the md5sum signature for the package
#
cd $buildir
md5sum $package.tgz > $package.md5
